# Self-Managed Elastic App Search Beta

Welcome to [Elastic App Search](https://www.elastic.co/cloud/app-search-service)!

You now have access to a set of robust APIs and unprecedented relevance controls.

With them, you can deliver amazing search experiences -- all backed by the Elastic Stack.

And for the first time, you can **serve it from your own infrastructure**.

## Beta

The self-managed version of Elastic App Search is currently in **beta**.

As you explore the offering, please provide feedback using the link within the application or send us email at: [app-search-beta-feedback@elastic.co](app-search-beta-feedback@elastic.co).

We would love to hear of your thoughts and any issues that you might experience.

Known issues and useful information will be kept up-to-date within the [App Search documentation](https://swiftype.com/documentation/app-search/self-managed/overview).

## Installation

### Supported platforms:

* Linux: x86_64 only
* MacOS X: High Sierra 10.13 - 10.1x (64 bit only)
* Windows: Not supported

### Minimum hardware:

* ~4GB of free RAM or 6GB if Elasticsearch is running on the same machine.
  * 2GB for App Server.
  * 2GB for Worker.
  * 50Mb for [Filebeat](https://www.elastic.co/products/beats/filebeat) and other processes.
* 5GB of disk space available.

### Dependencies:

* Install [Java 8](https://www.oracle.com/technetwork/java/javase/downloads/jdk8-downloads-2133151.html) or [Java 11](https://www.oracle.com/technetwork/java/javase/downloads/jdk11-downloads-5066655.html).
* Licensed [Elasticsearch](https://www.elastic.co/downloads/elasticsearch) >= 6.6.x, < 7.

### Notices:

* **Elasticsearch must have at least a Basic license**. A free Basic license is included when downloading Elasticsearch from [Elastic.co](https://www.elastic.co/downloads/elasticsearch), but not available within OSS versions like those acquired via a package manager like homebrew.
* When using security features within your Elastcisearch cluster, define a minimum [Elasticsearch role](https://www.elastic.co/guide/en/elasticsearch/reference/current/security-api-put-role.html):

```json
{
  "cluster" : [ "manage_index_templates", "monitor" ],
  "indices" : [
    {
      "names" : [ ".app-search-*" ],
      "privileges" : [ "manage", "write", "read" ]
    }
  ]
}
```
* Ensure that there are no pre-existing Elasticsearch indexes with: `.app-search-*`.
* [Dynamic Index Creation](https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-index_.html#index-creation) within Elasticsearch **must** be turned off for App Search indexes.
* API endpoints URLs do not require a **Host Identifier**. API requests only require the host (localhost for local test deployments), port, and API suffix. All first party clients have been updated to consider the **Host Identifier** optional:

```bash
## A managed service query with a Host Identifier:
curl -X POST 'https://host-2376rb.api.swiftype.com/api/as/v1/engines/national-parks-demo/search' \
-H 'Content-Type: application/json' \
-H 'Authorization: Bearer search-soaewu2ye6uc45dr8mcd54v8' \
-d '{
  "query": "everglade"
}'

## A self managed query without a Host Identifier:
curl -X POST 'http://localhost:3002/api/as/v1/engines/national-parks-demo/search' \
-H 'Content-Type: application/json' \
-H 'Authorization: Bearer search-soaewu2ye6uc45dr8mcd54v8' \
-d '{
  "query": "everglade"
}'
```

## Running App Search

Ensure Elasticsearch is running:

`bin/elasticsearch`

If you can run `curl http://localhost:9200/` to successfully reach Elasticsearch, then keep going!

Next, apply our recommended Elasticsearch cluster configuration.

To do so, choose **one** of the following methods:

1. Allow App Search to modify cluster settings. Add the following line to config/app_search.yml: allow_es_settings_modification: true.

2. Allow Elasticsearch to create indexes automatically. Add the following line to `elasticsearch.yml` or within your Elasticsearch cluster settings: `action.auto_create_index: ".app-search-*-logs-*,-.app-search-*,+*"`

After that, enter the App Search directory and run...

`bin/app-search`

After it starts, visit http://localhost:3002.

The default login credentials are:

* **Email**: app-search@example.com
* **Password**: changeme

Be sure to change the password once you login!

And now? Explore the [documentation](https://swiftype.com/documentation/app-search/getting-started), configure your `app_search.yml` file, index some data, explore the [Reference UI](https://swiftype.com/documentation/app-search/guides/reference-ui), perform search queries, tune relevance, and start building excellent search experiences.

## Using the API

An example search query:

```bash
curl -X POST 'http://localhost:3002/api/as/v1/engines/national-parks-demo/search' \
     -H 'Content-Type: application/json' \
     -H 'Authorization: Bearer search-************************' \
     -d '{ "query": "everglade" }'
```

## Configuration & Troubleshooting

For configuration details, troubleshooting, known issues, and other useful information, check out the [documentation](http://swiftype.com/documentation/app-search/self-managed/overview).
